==> bow-ui-0.5-sources.jar: org/chorem/bow/BowImportHelper.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public  class BowImportHelper {

    /**
     * BowImportHelper :
     * utility class all provided methods are accessible the static way
     */

    private BowImportHelper() {// empty
}

    /**
     * getImportDate :
     * @param wikitty 
     * @return Date 
     */

    public static Date getImportDate(Wikitty wikitty) {
        Date value = wikitty.getFieldAsDate(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE);
        return value;
}

    /**
     * setImportDate :
     * @param wikitty 
     * @param importDate 
     * @return Date 
     */

    public static Date setImportDate(Wikitty wikitty, Date importDate) {
        Date oldValue = getImportDate(wikitty);
        wikitty.setField(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE, importDate);
        return oldValue;
}

    /**
     * equals :
     * @param w1 
     * @param w2 
     * @return boolean 
     */

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE);
            Object f2 = w2.getFieldAsObject(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * isExtension :
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return boolean 
     */

    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * hasExtension :
     * check if wikitty has current extension
     * @param wikitty 
     * @return boolean 
     */

    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(BowImport.EXT_BOWIMPORT);
}

    /**
     * addExtension :
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */

    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowImportAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}


} //BowImportHelper

==> bow-ui-1.2-sources.jar: org/chorem/bow/BowImportHelper.java <==
package org.chorem.bow;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;

public class BowImportHelper {

    /**
     * utility class all provided methods are accessible the static way
     */
    private BowImportHelper() {// empty
}

    public static Date getImportDate(Wikitty wikitty) {
        Date value = wikitty.getFieldAsDate(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE);
        return value;
}

    public static Date setImportDate(Wikitty wikitty, Date importDate) {
        Date oldValue = getImportDate(wikitty);
        wikitty.setField(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE, importDate);
        return oldValue;
}

    public static boolean equals(Wikitty w1, Wikitty w2) {
    boolean result = true;

        if (result) {
            Object f1 = w1.getFieldAsObject(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE);
            Object f2 = w2.getFieldAsObject(BowImport.EXT_BOWIMPORT, BowImport.FIELD_BOWIMPORT_IMPORTDATE);
            result = f1 == f2 || (f1 != null && f1.equals(f2));
        };

    return result;
}

    /**
     * @deprecated renamed to keep consistency, use hasExtension instead
     * @param wikitty 
     * @return 
     */
    @Deprecated
    public static boolean isExtension(Wikitty wikitty) {
        return hasExtension(wikitty);
}

    /**
     * check if wikitty has current extension
     * @param wikitty 
     * @return 
     */
    public static boolean hasExtension(Wikitty wikitty) {
        return wikitty.hasExtension(BowImport.EXT_BOWIMPORT);
}

    /**
     * ajout les extensions static de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void addExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowImportAbstract.extensions) {
            wikitty.addExtension(ext);
        }
}

    /**
     * supprime les extensions de cette classe au wikitty en argument
     * @param wikitty 
     */
    public static void removeExtension(Wikitty wikitty) {
        for (WikittyExtension ext : BowImportAbstract.extensions) {
            wikitty.removeExtension(ext.getName());
        }
}

    /**
     * Return toString representation. Use tagValue 'toString' format, if exist, else standard toString is call
     * @param wikitty 
     * @return 
     */
    public static String toString(Wikitty wikitty) {

        return wikitty.toString(BowImport.EXT_BOWIMPORT);
}

} //BowImportHelper
